package controller

import (
	"github.com/gin-gonic/gin"
	"project_management/app/e"
	"project_management/app/model"
	"project_management/app/services"
	"project_management/unity"
)

var Capabilities services.Capabilities = &model.Capabilities{}

// GetCapabilities 获取所有能力
func GetCapabilities(c *gin.Context) {
	var params unity.QueryPageParams
	var capabilities model.Capabilities
	_, _, role := unity.GetUId(c)
	if err := c.ShouldBindJSON(&params); err != nil {
		e.ResponseWithMsg(c, e.JSONParsingFailed, e.JSONParsingFailed.GetMsg())
		return
	}
	queryCond := "cap_name like ?"
	params.Query = "%" + params.Query + "%"
	if role == "admin" {
		result, total, err := Capabilities.AdminGetCapabilitiesList(params, capabilities, queryCond)
		if err != nil {
			e.ResponseWithMsg(c, e.PaginationFailed, e.PaginationFailed.GetMsg())
			return
		}
		e.ResPonsePage(c, result, total, params)
		return
	}
	result, total, err := Capabilities.GetCapabilitiesList(params, capabilities, queryCond)
	if err != nil {
		e.ResponseWithMsg(c, e.PaginationFailed, e.PaginationFailed.GetMsg())
		return
	} else {
		e.ResPonsePage(c, result, total, params)
		return
	}
}

// AdminAddGetCapabilities 添加能力
func AdminAddGetCapabilities(c *gin.Context) {
	var capabilities model.Capabilities
	if err := c.ShouldBindJSON(&capabilities); err != nil {
		e.ResponseWithMsg(c, e.JSONParsingFailed, e.JSONParsingFailed.GetMsg())
		return
	}
	id := unity.RandomIds(4)
	for model.CapIdISRepeat(id) {
		id = unity.RandomIds(4)
	}
	capabilities.CapId = id
	addCapabilities := Capabilities.AddCapabilities(capabilities)
	if addCapabilities == e.SUCCESS {
		e.ResponseWithMsg(c, addCapabilities, addCapabilities.GetMsg())
		return
	}
	e.ResponseWithMsg(c, addCapabilities, addCapabilities.GetMsg())
}
